@@ -3,7 +3,7 @@ use warnings;
 
 package Pantry::App::Command::rename;
 # ABSTRACT: Implements pantry rename subcommand
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 use Pantry::App -command;
 use autodie;
@@ -18,23 +18,18 @@ sub command_type {
   return 'DUAL_TARGET';
 }
 
+my @types = qw/node role environment bag/;
+
 sub valid_types {
-  return qw/node role environment/
+  return @types;
 }
 
-sub _rename_node {
-  my ($self, $opt, $name, $dest) = @_;
-  return $self->_rename_obj($opt, 'node', $name, $dest);
-}
-
-sub _rename_role {
-  my ($self, $opt, $name, $dest) = @_;
-  return $self->_rename_obj($opt, 'role', $name, $dest);
-}
-
-sub _rename_environment {
-  my ($self, $opt, $name, $dest) = @_;
-  return $self->_rename_obj($opt, 'environment', $name, $dest);
+for my $t (@types) {
+  no strict 'refs';
+  *{"_rename_$t"} = sub {
+    my ($self, $opt, $name, $dest) = @_;
+    return $self->_rename_obj($opt, $t, $name, $dest);
+  };
 }
 
 sub _rename_obj {
@@ -69,6 +64,7 @@ sub _rename_obj {
 # vim: ts=2 sts=2 sw=2 et:
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -77,7 +73,7 @@ Pantry::App::Command::rename - Implements pantry rename subcommand
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -103,4 +99,3 @@ This is free software, licensed under:
   The Apache License, Version 2.0, January 2004
 
 =cut
-
